Module api

Module api 

Definitions of the PostGuard protocol REST API.

Structs

DisclosureAttribute
An attribute in a disclosure request, extending Attribute with an optional flag.
IrmaAuthRequest
An authentication request for a IRMA identity.
KeyResponse
The key response from the Private Key Generator (PKG).
Parameters
The public parameters of the Private Key Generator (PKG).
SigningKeyRequest
The request Signing key request body.
SigningKeyResponse
The signing key response from the Private Key Generator (PKG).