Module consts

Module consts 

Constants used in the PostGuard protocol.

Constants

HEADER_SIZE_SIZE
The size of the header size.
IV_SIZE
Size of the initialization vector.
KEY_SIZE
Size of the symmetric key.
MAX_HEADER_SIZE
The maximum size of the header (1 MiB).
MAX_SIG_SIZE
The maximum size of the serialized header signature (8 KiB).
MAX_SYMMETRIC_CHUNK_SIZE
The maximum size of symmetric segments (4 MiB).
POL_SIZE_SIZE
The size of the policy size.
PREAMBLE_SIZE
The preamble contains the following bytes:
PRELUDE
The tag bytes with which all PostGuard bytestreams begin.
PRELUDE_SIZE
The size of the tag with which all PostGuard bytestreams begin.
SIG_SIZE_SIZE
The size of the signature size.
STREAM_NONCE_SIZE
Size of the nonce in the “STREAM” encryption construction.
SYMMETRIC_CRYPTO_DEFAULT_CHUNK
Default size of symmetric encryption segments, if in streaming mode.
TAG_SIZE
Size of the authentication tag. The authentication tag is appended to each segment.
VERSION_0
Version 0 (legacy).
VERSION_1
Version 1 (legacy).
VERSION_2
Version 2.
VERSION_SIZE
The size of the version identifier.
VERSION_V1Deprecated
Deprecated alias for VERSION_0.
VERSION_V2Deprecated
Deprecated alias for VERSION_1.
VERSION_V3Deprecated
Deprecated alias for VERSION_2.