Identity definitions and utilities.
Structs
- Attribute
- A PostGuard IRMA attribute, which is a simple case of an IRMA ConDisCon.
- Hidden
Policy - An PostGuard hidden policy.
- Policy
- An PostGuard policy used to encapsulate a shared secret for one recipient.
Functions
- canonicalize
- Canonicalizes an attribute value for the given attribute type.
- is_
canonical - Whether a value is already in the canonical form its attribute type expects.
Type Aliases
- Encryption
Policy - The complete encryption policy for all recipients.